Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewEncoder ¶
func NewEncoder() matchfinder.Encoder
func NewGZIPEncoder ¶
func NewGZIPEncoder() matchfinder.Encoder
func NewGZIPWriter ¶
func NewGZIPWriter(w io.Writer, level int) *matchfinder.Writer
NewGZIPWriter returns a new matchfinder.Writer that compresses data at the given level, in gzip encoding. Levels 1–9 are available; levels outside this range will be replaced by the closest level available.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.